Documentation
=============


[![image](https://img.shields.io/travis/TankerHQ/cloudmesh-bar.svg?branch=main)](https://travis-ci.org/TankerHQ/cloudmesn-bar)

[![image](https://img.shields.io/pypi/pyversions/cloudmesh-bar.svg)](https://pypi.org/project/cloudmesh-bar)

[![image](https://img.shields.io/pypi/v/cloudmesh-bar.svg)](https://pypi.org/project/cloudmesh-bar/)

[![image](https://img.shields.io/github/license/TankerHQ/python-cloudmesh-bar.svg)](https://github.com/TankerHQ/python-cloudmesh-bar/blob/main/LICENSE)

see cloudmesh.cmd5

* https://github.com/cloudmesh/cloudmesh.cmd5


## TODO

* create gh class
* develop api for most useful things for us

What is most useful

* create repo given name in csv file with
  * firstname, lastname, githubid, hid (hid we define and is incremental number, hid<number>) 
  * add README.md
  * add LICENSE
  * add a directory copy from a sample repo
    * latex document
    * markdown document
    * cloudmesh dir with small readme how to create a cms command
  